@@ -2,7 +2,6 @@ from typing import Tuple, List
 
 import requests
 import whois
-from termcolor import colored
 from requests.packages.urllib3.util import Retry
 from requests.adapters import HTTPAdapter
 from requests import Session
@@ -41,10 +40,12 @@ class PageChecker(Plugin):
                 status_code = s.head(
                     url, allow_redirects=True, timeout=TIMEOUT
                 ).status_code
+            self.logger.info(w)
         except requests.exceptions.ConnectTimeout:
             status_code = 408
+        except Exception:
+            status_code = 400
 
-        self.logger.info(w)
         output_strng = {
             "status": status_code,
             "url": url,
@@ -69,9 +70,7 @@ class PageChecker(Plugin):
                     else:
                         color = "cyan"
                     other = {
-                        colored(data[directive]["url"], color): colored(
-                            data[directive]["status"], color
-                        )
+                        f"[{color}]{data[directive]['url']}": f"[{color}]{data[directive]['status']}"
                     }
                 except KeyError:
                     other = {}
